# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-07-24 08:32
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0005_auto_20170719_1454'),
        ('codenerix_invoicing', '0021_auto_20170531_1407'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pos',
            name='billing_series',
        ),
        migrations.RemoveField(
            model_name='salesbasket',
            name='point_sales',
        ),
        migrations.RemoveField(
            model_name='salesinvoice',
            name='tax',
        ),
        migrations.AddField(
            model_name='salesbasket',
            name='pos_slot',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='basket_sales', to='codenerix_pos.POSSlot', verbose_name='Point of Sales'),
        ),
        migrations.AddField(
            model_name='salesinvoice',
            name='billing_series',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_sales', to='codenerix_invoicing.BillingSeries', verbose_name=b'Billing series'),
            preserve_default=False,
        ),
        migrations.DeleteModel(
            name='POS',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-07-26 18:30
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0023_customer_default_customer'),
    ]

    operations = [
        migrations.AlterField(
            model_name='saleslineorder',
            name='line_budget',
            field=models.OneToOneField(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='line_order_sales', to='codenerix_invoicing.SalesLineBasket', verbose_name='Line budget'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-21 11:40
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0053_auto_20170919_1231'),
    ]

    operations = [
        migrations.AddField(
            model_name='purchasesalbarandocument',
            name='created',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='Created'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='purchasesalbarandocument',
            name='updated',
            field=models.DateTimeField(auto_now=True, verbose_name='Updated'),
        ),
        migrations.AddField(
            model_name='purchasesbudgetdocument',
            name='created',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='Created'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='purchasesbudgetdocument',
            name='updated',
            field=models.DateTimeField(auto_now=True, verbose_name='Updated'),
        ),
        migrations.AddField(
            model_name='purchasesinvoicedocument',
            name='created',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='Created'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='purchasesinvoicedocument',
            name='updated',
            field=models.DateTimeField(auto_now=True, verbose_name='Updated'),
        ),
        migrations.AddField(
            model_name='purchasesinvoicerectificationdocument',
            name='created',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='Created'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='purchasesinvoicerectificationdocument',
            name='updated',
            field=models.DateTimeField(auto_now=True, verbose_name='Updated'),
        ),
        migrations.AddField(
            model_name='purchasesorderdocument',
            name='created',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='Created'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='purchasesorderdocument',
            name='updated',
            field=models.DateTimeField(auto_now=True, verbose_name='Updated'),
        ),
        migrations.AddField(
            model_name='purchasesticketdocument',
            name='created',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='Created'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='purchasesticketdocument',
            name='updated',
            field=models.DateTimeField(auto_now=True, verbose_name='Updated'),
        ),
        migrations.AddField(
            model_name='purchasesticketrectificationdocument',
            name='created',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='Created'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='purchasesticketrectificationdocument',
            name='updated',
            field=models.DateTimeField(auto_now=True, verbose_name='Updated'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-08 17:36
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_payments', '0018_auto_20170303_0839'),
        ('codenerix_invoicing', '0003_auto_20170301_1411'),
    ]

    operations = [
        migrations.AddField(
            model_name='salesbudget',
            name='payment',
            field=models.ManyToManyField(blank=True, related_name='budget_sales', to='codenerix_payments.PaymentRequest', verbose_name='Payment Request'),
        ),
        migrations.AddField(
            model_name='salesorder',
            name='payment',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='order_sales', to='codenerix_payments.PaymentRequest', verbose_name='Payment Request'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-09 11:52
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0005_auto_20170309_1114'),
    ]

    operations = [
        migrations.AddField(
            model_name='salesorder',
            name='budget',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='order_sales', to='codenerix_invoicing.SalesBudget', verbose_name='Budget'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-19 07:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0050_auto_20170919_0025'),
    ]

    operations = [
        migrations.AddField(
            model_name='cashdiary',
            name='opened_cards_extra',
            field=models.FloatField(blank=True, default=None, null=True, verbose_name='Opened Cards Deviation'),
        ),
        migrations.AddField(
            model_name='cashdiary',
            name='opened_cash_extra',
            field=models.FloatField(blank=True, default=None, null=True, verbose_name='Opened Cash Deviation'),
        ),
        migrations.AlterField(
            model_name='cashdiary',
            name='closed_cards_extra',
            field=models.FloatField(blank=True, default=None, null=True, verbose_name='Closed Cards Deviation'),
        ),
        migrations.AlterField(
            model_name='cashdiary',
            name='closed_cash_extra',
            field=models.FloatField(blank=True, default=None, null=True, verbose_name='Closed Cash Deviation'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-01 10:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0033_auto_20170901_0939'),
    ]

    operations = [
        migrations.AlterField(
            model_name='saleslinebasket',
            name='discount',
            field=models.FloatField(default=0, verbose_name='Discount (%)'),
        ),
        migrations.AlterField(
            model_name='saleslinebasket',
            name='price',
            field=models.FloatField(verbose_name='Price base'),
        ),
        migrations.AlterField(
            model_name='saleslinebasket',
            name='price_recommended',
            field=models.FloatField(verbose_name='Recomended price base'),
        ),
        migrations.AlterField(
            model_name='saleslineinvoice',
            name='discount',
            field=models.FloatField(default=0, verbose_name='Discount (%)'),
        ),
        migrations.AlterField(
            model_name='saleslineinvoice',
            name='price',
            field=models.FloatField(verbose_name='Price base'),
        ),
        migrations.AlterField(
            model_name='saleslineinvoice',
            name='price_recommended',
            field=models.FloatField(verbose_name='Recomended price base'),
        ),
        migrations.AlterField(
            model_name='saleslineorder',
            name='discount',
            field=models.FloatField(default=0, verbose_name='Discount (%)'),
        ),
        migrations.AlterField(
            model_name='saleslineorder',
            name='price',
            field=models.FloatField(verbose_name='Price base'),
        ),
        migrations.AlterField(
            model_name='saleslineorder',
            name='price_recommended',
            field=models.FloatField(verbose_name='Recomended price base'),
        ),
        migrations.AlterField(
            model_name='saleslineticket',
            name='discount',
            field=models.FloatField(default=0, verbose_name='Discount (%)'),
        ),
        migrations.AlterField(
            model_name='saleslineticket',
            name='price',
            field=models.FloatField(verbose_name='Price base'),
        ),
        migrations.AlterField(
            model_name='saleslineticket',
            name='price_recommended',
            field=models.FloatField(verbose_name='Recomended price base'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-30 13:08
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0029_auto_20170816_1249'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='salesticket',
            name='tax',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-06 14:36
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0041_auto_20170905_1349'),
    ]

    operations = [
        migrations.AddField(
            model_name='salesalbaran',
            name='billing_series',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='albaran_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AddField(
            model_name='salesalbaran',
            name='code_counter',
            field=models.IntegerField(default=0, editable=False, verbose_name='Code counter'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='salesbasket',
            name='billing_series',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='basket_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AddField(
            model_name='salesbasket',
            name='code_counter',
            field=models.IntegerField(default=0, editable=False, verbose_name='Code counter'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='salesinvoice',
            name='code_counter',
            field=models.IntegerField(default=0, editable=False, verbose_name='Code counter'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='salesinvoicerectification',
            name='billing_series',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoicerectivication_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AddField(
            model_name='salesinvoicerectification',
            name='code_counter',
            field=models.IntegerField(default=0, editable=False, verbose_name='Code counter'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='salesorder',
            name='billing_series',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='order_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AddField(
            model_name='salesorder',
            name='code_counter',
            field=models.IntegerField(default=0, editable=False, verbose_name='Code counter'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='salesticket',
            name='billing_series',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='ticket_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AddField(
            model_name='salesticket',
            name='code_counter',
            field=models.IntegerField(default=0, editable=False, verbose_name='Code counter'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='salesticketrectification',
            name='billing_series',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='ticketrectification_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AddField(
            model_name='salesticketrectification',
            name='code_counter',
            field=models.IntegerField(default=0, editable=False, verbose_name='Code counter'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='customer',
            name='billing_series',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='billing_series', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AlterField(
            model_name='printcounterdocumentalbaran',
            name='status_document',
            field=models.CharField(choices=[('TM', 'Temporary'), ('DF', 'Definitive')], default='TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AlterField(
            model_name='printcounterdocumentbasket',
            name='status_document',
            field=models.CharField(choices=[('TM', 'Temporary'), ('DF', 'Definitive')], default='TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AlterField(
            model_name='printcounterdocumentinvoice',
            name='status_document',
            field=models.CharField(choices=[('TM', 'Temporary'), ('DF', 'Definitive')], default='TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AlterField(
            model_name='printcounterdocumentinvoicerectification',
            name='status_document',
            field=models.CharField(choices=[('TM', 'Temporary'), ('DF', 'Definitive')], default='TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AlterField(
            model_name='printcounterdocumentorder',
            name='status_document',
            field=models.CharField(choices=[('TM', 'Temporary'), ('DF', 'Definitive')], default='TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AlterField(
            model_name='printcounterdocumentticket',
            name='status_document',
            field=models.CharField(choices=[('TM', 'Temporary'), ('DF', 'Definitive')], default='TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AlterField(
            model_name='printcounterdocumentticketrectification',
            name='status_document',
            field=models.CharField(choices=[('TM', 'Temporary'), ('DF', 'Definitive')], default='TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AlterField(
            model_name='provider',
            name='billing_series',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='providers', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AlterField(
            model_name='provider',
            name='finance_surcharge',
            field=models.CharField(blank=True, choices=[('I', 'Taxable base'), ('F', 'Total bill')], max_length=1, null=True, verbose_name='Finance surcharge'),
        ),
        migrations.AlterField(
            model_name='provider',
            name='payment_methods',
            field=models.CharField(blank=True, choices=[('AMA', 'Amazon'), ('TRA', 'Wire transfer'), ('CAR', 'Card'), ('CAS', 'Cash'), ('CRE', 'Credit'), ('PYP', 'Paypal'), ('30C', '30 day credit'), ('60C', '60 day credit'), ('90C', '90 day credit')], max_length=3, null=True, verbose_name='Payment methods'),
        ),
        migrations.AlterField(
            model_name='purchaseslinealbaran',
            name='status',
            field=models.CharField(blank=True, choices=[('PR', 'Pending review'), ('RV', 'Reviewed'), ('RC', 'Rejected')], default='PR', max_length=2, null=True, verbose_name='Status'),
        ),
        migrations.AlterField(
            model_name='salesbasket',
            name='role',
            field=models.CharField(choices=[('SC', 'Shopping cart'), ('BU', 'Budget'), ('WL', 'Wish list')], default='SC', max_length=2, verbose_name='Role basket'),
        ),
        migrations.AlterField(
            model_name='salesinvoice',
            name='billing_series',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='invoice_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AlterField(
            model_name='salesorder',
            name='payment_detail',
            field=models.CharField(blank=True, choices=[('AMA', 'Amazon'), ('TRA', 'Wire transfer'), ('CAR', 'Card'), ('CAS', 'Cash'), ('CRE', 'Credit'), ('PYP', 'Paypal'), ('30C', '30 day credit'), ('60C', '60 day credit'), ('90C', '90 day credit')], max_length=3, null=True, verbose_name='Payment detail'),
        ),
        migrations.AlterField(
            model_name='salesorder',
            name='status_order',
            field=models.CharField(choices=[('PE', 'Pending'), ('PA', 'Payment accepted'), ('SE', 'Sent'), ('DE', 'Delivered')], default='PE', max_length=2, verbose_name='Status'),
        ),
        migrations.AlterField(
            model_name='stockmovement',
            name='status',
            field=models.CharField(choices=[('R', 'Requested'), ('S', 'Sent'), ('D', 'Delivered')], default='R', max_length=1, verbose_name='Status'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-05 12:53
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0011_auto_20170327_1014'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='salesbudget',
            unique_together=set([]),
        ),
        migrations.RemoveField(
            model_name='salesbudget',
            name='customer',
        ),
        migrations.RemoveField(
            model_name='salesbudget',
            name='payment',
        ),
        migrations.RemoveField(
            model_name='salesbudget',
            name='shopping_cart',
        ),
        migrations.RemoveField(
            model_name='saleslinebudget',
            name='budget',
        ),
        migrations.RemoveField(
            model_name='saleslinebudget',
            name='product',
        ),
        migrations.RemoveField(
            model_name='saleslinesalesshoppingcart',
            name='product',
        ),
        migrations.RemoveField(
            model_name='saleslinesalesshoppingcart',
            name='shoppingcart',
        ),
        migrations.RemoveField(
            model_name='salesshoppingcart',
            name='customer',
        ),
        migrations.AlterField(
            model_name='saleslineorder',
            name='line_budget',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='line_order_sales', to='codenerix_invoicing.SalesLineBasket', verbose_name='Line budget'),
        ),
        migrations.AlterField(
            model_name='salesorder',
            name='budget',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='order_sales', to='codenerix_invoicing.SalesBasket', verbose_name='Budget'),
        ),
        migrations.DeleteModel(
            name='SalesBudget',
        ),
        migrations.DeleteModel(
            name='SalesLineBudget',
        ),
        migrations.DeleteModel(
            name='SalesLineSalesShoppingCart',
        ),
        migrations.DeleteModel(
            name='SalesShoppingCart',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-04 11:17
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('codenerix_invoicing', '0036_auto_20170904_1049'),
    ]

    operations = [
        migrations.CreateModel(
            name='ReasonModification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('code', models.CharField(max_length=15, unique=True, verbose_name='Code')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('enable', models.BooleanField(default=True, verbose_name='Enable')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ReasonModificationLineAlbaran',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('date', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Date')),
                ('line', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_albaran', to='codenerix_invoicing.SalesLineAlbaran', verbose_name='Line')),
                ('reason', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_albaran', to='codenerix_invoicing.ReasonModification', verbose_name='Reason')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_albaran', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ReasonModificationLineBasket',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('date', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Date')),
                ('line', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_basket', to='codenerix_invoicing.SalesLineBasket', verbose_name='Line')),
                ('reason', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_basket', to='codenerix_invoicing.ReasonModification', verbose_name='Reason')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_basket', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ReasonModificationLineInvoice',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('date', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Date')),
                ('line', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_invoice', to='codenerix_invoicing.SalesLineInvoice', verbose_name='Line')),
                ('reason', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_invoice', to='codenerix_invoicing.ReasonModification', verbose_name='Reason')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_invoice', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ReasonModificationLineInvoiceRectification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('date', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Date')),
                ('line', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_invoice_rectification', to='codenerix_invoicing.SalesLineInvoiceRectification', verbose_name='Line')),
                ('reason', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_invoice_rectification', to='codenerix_invoicing.ReasonModification', verbose_name='Reason')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_invoice_rectification', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ReasonModificationLineOrder',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('date', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Date')),
                ('line', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_order', to='codenerix_invoicing.SalesLineOrder', verbose_name='Line')),
                ('reason', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_order', to='codenerix_invoicing.ReasonModification', verbose_name='Reason')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_order', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ReasonModificationLineTicket',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('date', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Date')),
                ('line', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_ticket', to='codenerix_invoicing.SalesLineTicket', verbose_name='Line')),
                ('reason', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_ticket', to='codenerix_invoicing.ReasonModification', verbose_name='Reason')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_ticket', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ReasonModificationLineTicketRectification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('date', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Date')),
                ('line', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_ticket_rectification', to='codenerix_invoicing.SalesLineTicketRectification', verbose_name='Line')),
                ('reason', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_ticket_rectification', to='codenerix_invoicing.ReasonModification', verbose_name='Reason')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='reason_line_ticket_rectification', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-29 06:45
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


def get_cash_dary(model, date_movement):
    info = {
        'opened_date__year': date_movement.year,
        'opened_date__month': date_movement.month,
        'opened_date__day': date_movement.day,
        'opened_date__hour': date_movement.hour,
        'opened_date__minute': date_movement.minute
    }
    cash_diary = model.objects.filter(**info).first()
    if cash_diary is None:
        info.pop('opened_date__minute')
        cash_diary = model.objects.filter(**info).first()
        if cash_diary is None:
            info.pop('opened_date__hour')
            cash_diary = model.objects.filter(**info).first()
            if cash_diary is None:
                info.pop('opened_date__day')
                cash_diary = model.objects.filter(**info).first()
                if cash_diary is None:
                    info.pop('opened_date__month')
                    cash_diary = model.objects.filter(**info).first()
                    if cash_diary is None:
                        info.pop('opened_date__year')
                        cash_diary = model.objects.filter(**info).first()
                        if cash_diary is None:
                            cash_diary = model.objects.all().first()
                            if cash_diary is None:
                                raise Exception('CashDiary not found. Create one CashDiary for continue')
    return cash_diary


def run_migrate(apps, schema_editor):
    CashDiary = apps.get_model("codenerix_invoicing", "CashDiary")
    CashMovement = apps.get_model("codenerix_invoicing", "CashMovement")
    for x in CashMovement.objects.filter(cash_diary__isnull=True):
        cash_diary = get_cash_dary(CashDiary, x.date_movement)
        x.cash_diary = cash_diary
        x.save()


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0056_cashmovement_reason'),
    ]

    operations = [
        migrations.RunPython(run_migrate),
        migrations.AlterField(
            model_name='cashmovement',
            name='cash_diary',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='cash_movements', to='codenerix_invoicing.CashDiary', verbose_name='Cash diary'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-06 18:57
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0043_auto_20170906_1925'),
    ]

    operations = [
        migrations.AlterField(
            model_name='salesalbaran',
            name='billing_series',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='albaran_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AlterField(
            model_name='salesbasket',
            name='billing_series',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='basket_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AlterField(
            model_name='salesinvoicerectification',
            name='billing_series',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='invoicerectification_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AlterField(
            model_name='salesorder',
            name='billing_series',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='order_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AlterField(
            model_name='salesticket',
            name='billing_series',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='ticket_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
        migrations.AlterField(
            model_name='salesticketrectification',
            name='billing_series',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='ticketrectification_sales', to='codenerix_invoicing.BillingSeries', verbose_name='Billing series'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-07 16:59
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0046_cashdiary_cashmovement'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cashdiary',
            name='closed_amount',
            field=models.FloatField(blank=True, null=True, verbose_name='Closed Amount'),
        ),
        migrations.AlterField(
            model_name='cashdiary',
            name='closed_date',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Closed Date'),
        ),
        migrations.AlterField(
            model_name='cashdiary',
            name='closed_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='closed_cash_diarys', to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-04 14:36
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0030_productfinaloption_productfinaloptiontexten_productfinaloptiontextes'),
        ('codenerix_invoicing', '0027_saleslinebasketoption_quantity'),
    ]

    operations = [
        migrations.CreateModel(
            name='SalesLineOrderOption',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('quantity', models.FloatField(verbose_name='Quantity')),
                ('line_order', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='line_order_option_sales', to='codenerix_invoicing.SalesLineOrder', verbose_name='Line Order')),
                ('product_final', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='line_order_option_sales', to='codenerix_products.ProductFinal', verbose_name='Product')),
                ('product_option', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='line_order_option_sales', to='codenerix_products.ProductFinalOption', verbose_name='Option')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-03 18:14
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0025_saleslinebasketoption'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='saleslinebasketoption',
            name='description',
        ),
        migrations.RemoveField(
            model_name='saleslinebasketoption',
            name='discount',
        ),
        migrations.RemoveField(
            model_name='saleslinebasketoption',
            name='notes',
        ),
        migrations.RemoveField(
            model_name='saleslinebasketoption',
            name='price',
        ),
        migrations.RemoveField(
            model_name='saleslinebasketoption',
            name='price_recommended',
        ),
        migrations.RemoveField(
            model_name='saleslinebasketoption',
            name='quantity',
        ),
        migrations.RemoveField(
            model_name='saleslinebasketoption',
            name='tax',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-19 11:34
from __future__ import unicode_literals

import codenerix.fields
import codenerix.lib.helpers
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0015_auto_20170405_1521'),
    ]

    operations = [
        migrations.CreateModel(
            name='Haulier',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name', models.CharField(max_length=128, unique=True, verbose_name='Name')),
                ('url_public', models.CharField(blank=True, max_length=250, null=True, verbose_name='Url public')),
                ('url_tracking', models.CharField(blank=True, max_length=250, null=True, verbose_name='Url tracking')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='salesorder',
            name='number_tracking',
            field=models.CharField(blank=True, max_length=128, null=True, verbose_name='Number of tracking'),
        ),
        migrations.AddField(
            model_name='salesorder',
            name='haulier',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='order_sales', to='codenerix_invoicing.Haulier', verbose_name='Haulier'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-09 17:46
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0006_salesorder_budget'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='saleslinebudget',
            name='type_tax',
        ),
        migrations.RemoveField(
            model_name='saleslineorder',
            name='type_tax',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-31 14:07
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0020_salesbasket_expiration_date'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='salesorder',
            name='haulier',
        ),
        migrations.AddField(
            model_name='salesbasket',
            name='haulier',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='basket_sales', to='codenerix_invoicing.Haulier', verbose_name='Haulier'),
        ),
        migrations.AlterField(
            model_name='salesbasket',
            name='address_delivery',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='order_sales_delivery', to='codenerix_invoicing.Address', verbose_name='Address delivery'),
        ),
        migrations.AlterField(
            model_name='salesbasket',
            name='address_invoice',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='order_sales_invoice', to='codenerix_invoicing.Address', verbose_name='Address invoice'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-14 15:49
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0004_auto_20170307_1045'),
        ('codenerix_payments', '0018_auto_20170303_0839'),
        ('codenerix_invoicing', '0007_auto_20170309_1746'),
    ]

    operations = [
        migrations.CreateModel(
            name='SalesBasket',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('lock', models.BooleanField(default=False, verbose_name='Lock')),
                ('parent_pk', models.IntegerField(blank=True, null=True, verbose_name='Parent pk')),
                ('code', models.CharField(max_length=64, verbose_name='Code')),
                ('date', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Date')),
                ('observations', models.TextField(blank=True, max_length=256, null=True, verbose_name='Observations')),
                ('rol', models.CharField(choices=[((b'SC',), 'Shopping cart'), (b'BU', 'Budget'), (b'WL', 'Wish list')], default=(b'SC',), max_length=2, verbose_name='Rol basket')),
                ('signed', models.BooleanField(default=False, verbose_name='Signed')),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
                ('customer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='basket_sales', to='codenerix_invoicing.Customer', verbose_name='Customer')),
                ('payment', models.ManyToManyField(blank=True, related_name='basket_sales', to='codenerix_payments.PaymentRequest', verbose_name='Payment Request')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SalesLineBasket',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('quantity', models.FloatField(verbose_name='Quantity')),
                ('notes', models.CharField(blank=True, max_length=256, null=True, verbose_name='Notes')),
                ('price_recommended', models.FloatField(verbose_name='Recomended price')),
                ('description', models.CharField(blank=True, max_length=256, null=True, verbose_name='Description')),
                ('discount', models.FloatField(default=0, verbose_name='Discount')),
                ('price', models.FloatField(verbose_name='Price')),
                ('tax', models.FloatField(blank=True, default=0, null=True, verbose_name='Tax')),
                ('basket', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='line_basket_sales', to='codenerix_invoicing.Customer', verbose_name='Basket')),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='line_basket_sales', to='codenerix_products.ProductFinal', verbose_name='Product')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AlterUniqueTogether(
            name='salesbasket',
            unique_together=set([('code', 'parent_pk')]),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-05 12:54
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0012_auto_20170405_1253'),
    ]

    operations = [
        migrations.RenameField(
            model_name='salesbasket',
            old_name='rol',
            new_name='role',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-03 17:35
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0030_productfinaloption_productfinaloptiontexten_productfinaloptiontextes'),
        ('codenerix_invoicing', '0024_auto_20170726_1830'),
    ]

    operations = [
        migrations.CreateModel(
            name='SalesLineBasketOption',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('quantity', models.FloatField(verbose_name='Quantity')),
                ('notes', models.CharField(blank=True, max_length=256, null=True, verbose_name='Notes')),
                ('price_recommended', models.FloatField(verbose_name='Recomended price')),
                ('description', models.CharField(blank=True, max_length=256, null=True, verbose_name='Description')),
                ('discount', models.FloatField(default=0, verbose_name='Discount')),
                ('price', models.FloatField(verbose_name='Price')),
                ('tax', models.FloatField(blank=True, default=0, null=True, verbose_name='Tax')),
                ('line_budget', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='line_basket_option_sales', to='codenerix_invoicing.SalesLineBasket', verbose_name='Line budget')),
                ('product_final', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='line_basket_option_sales', to='codenerix_products.ProductFinal', verbose_name='Product')),
                ('product_option', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='line_basket_option_sales', to='codenerix_products.ProductFinalOption', verbose_name='Option')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-23 17:24
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0008_auto_20170314_1549'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='purchasesalbaran',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesalbarandocument',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesbudget',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesbudgetdocument',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesinvoice',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesinvoicedocument',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesinvoicerectification',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesinvoicerectificationdocument',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchaseslinealbaran',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchaseslinebudget',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchaseslineinvoice',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchaseslineinvoicerectification',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchaseslineorder',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchaseslineticket',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchaseslineticketrectification',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesorder',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesorderdocument',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesticket',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesticketdocument',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesticketrectification',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='purchasesticketrectificationdocument',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='salesalbaran',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='salesbasket',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='salesbudget',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list'), 'verbose_name': 'Budget', 'verbose_name_plural': 'Budgets'},
        ),
        migrations.AlterModelOptions(
            name='salesinvoice',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='salesinvoicerectification',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='saleslinealbaran',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='saleslinebasket',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='saleslinebudget',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='saleslineinvoice',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='saleslineinvoicerectification',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='saleslineorder',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='saleslineticket',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='saleslineticketrectification',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='salesorder',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='salesticket',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='salesticketrectification',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='typedocumenttexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='typedocumenttextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='wishlist',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterUniqueTogether(
            name='salesbudget',
            unique_together=set([('code', 'parent_pk')]),
        ),
        migrations.AlterUniqueTogether(
            name='salesinvoicerectification',
            unique_together=set([('code', 'parent_pk')]),
        ),
        migrations.AlterUniqueTogether(
            name='salesticketrectification',
            unique_together=set([('code', 'parent_pk')]),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-24 14:04
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0059_auto_20171123_1019'),
    ]

    operations = [
        migrations.AddField(
            model_name='saleslinebasket',
            name='code',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Code'),
        ),
        migrations.AddField(
            model_name='saleslineinvoice',
            name='code',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Code'),
        ),
        migrations.AddField(
            model_name='saleslineorder',
            name='code',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Code'),
        ),
        migrations.AddField(
            model_name='saleslineticket',
            name='code',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Code'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-06 17:25
from __future__ import unicode_literals

from django.db import migrations

from codenerix_invoicing.models_sales import SalesAlbaran, SalesBasket, SalesInvoiceRectification, SalesOrder, SalesTicket, SalesTicketRectification
from codenerix_invoicing.models import BillingSeries


def run_migrate(apps, schema_editor):
    for model in [SalesAlbaran, SalesBasket, SalesInvoiceRectification, SalesOrder, SalesTicket, SalesTicketRectification]:
        i = 1
        for obj in model.objects.all().order_by("pk"):
            obj.code_counter = i
            obj.code = str(i)
            obj.billing_series_id = BillingSeries.objects.all().first().pk
            obj.save(force_save=True)
            i += 1


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0042_auto_20170906_1636'),
    ]

    operations = [
        migrations.RunPython(run_migrate),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-01 07:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0032_auto_20170831_1828'),
    ]

    operations = [
        migrations.AddField(
            model_name='salesalbaran',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
        migrations.AddField(
            model_name='salesbasket',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
        migrations.AddField(
            model_name='salesinvoice',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
        migrations.AddField(
            model_name='salesinvoicerectification',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
        migrations.AddField(
            model_name='salesorder',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
        migrations.AddField(
            model_name='salesticket',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
        migrations.AddField(
            model_name='salesticketrectification',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-04 16:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0039_printcounterdocumentalbaran_printcounterdocumentbasket_printcounterdocumentinvoice_printcounterdocum'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='printcounterdocumentalbaran',
            name='quantity',
        ),
        migrations.RemoveField(
            model_name='printcounterdocumentbasket',
            name='quantity',
        ),
        migrations.RemoveField(
            model_name='printcounterdocumentinvoice',
            name='quantity',
        ),
        migrations.RemoveField(
            model_name='printcounterdocumentinvoicerectification',
            name='quantity',
        ),
        migrations.RemoveField(
            model_name='printcounterdocumentorder',
            name='quantity',
        ),
        migrations.RemoveField(
            model_name='printcounterdocumentticket',
            name='quantity',
        ),
        migrations.RemoveField(
            model_name='printcounterdocumentticketrectification',
            name='quantity',
        ),
        migrations.AddField(
            model_name='printcounterdocumentalbaran',
            name='status_document',
            field=models.CharField(choices=[(b'TM', 'Temporary'), (b'DF', 'Definitive')], default=b'TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AddField(
            model_name='printcounterdocumentbasket',
            name='status_document',
            field=models.CharField(choices=[(b'TM', 'Temporary'), (b'DF', 'Definitive')], default=b'TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AddField(
            model_name='printcounterdocumentinvoice',
            name='status_document',
            field=models.CharField(choices=[(b'TM', 'Temporary'), (b'DF', 'Definitive')], default=b'TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AddField(
            model_name='printcounterdocumentinvoicerectification',
            name='status_document',
            field=models.CharField(choices=[(b'TM', 'Temporary'), (b'DF', 'Definitive')], default=b'TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AddField(
            model_name='printcounterdocumentorder',
            name='status_document',
            field=models.CharField(choices=[(b'TM', 'Temporary'), (b'DF', 'Definitive')], default=b'TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AddField(
            model_name='printcounterdocumentticket',
            name='status_document',
            field=models.CharField(choices=[(b'TM', 'Temporary'), (b'DF', 'Definitive')], default=b'TM', max_length=2, verbose_name='Status document'),
        ),
        migrations.AddField(
            model_name='printcounterdocumentticketrectification',
            name='status_document',
            field=models.CharField(choices=[(b'TM', 'Temporary'), (b'DF', 'Definitive')], default=b'TM', max_length=2, verbose_name='Status document'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-18 22:04
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0048_auto_20170915_2341'),
    ]

    operations = [
        migrations.AddField(
            model_name='cashdiary',
            name='checked',
            field=models.BooleanField(default=False, verbose_name='Checked'),
        ),
        migrations.AddField(
            model_name='cashdiary',
            name='notes',
            field=models.TextField(blank=True, null=True, verbose_name='Notes'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-05 13:44
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0013_auto_20170405_1254'),
    ]

    operations = [
        migrations.AddField(
            model_name='pos',
            name='default',
            field=models.BooleanField(default=False, verbose_name='Default'),
        ),
        migrations.AlterField(
            model_name='salesbasket',
            name='role',
            field=models.CharField(choices=[(b'SC', 'Shopping cart'), (b'BU', 'Budget'), (b'WL', 'Wish list')], default=b'SC', max_length=2, verbose_name='Role basket'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-05 15:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0014_auto_20170405_1344'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='wishlist',
            unique_together=set([]),
        ),
        migrations.RemoveField(
            model_name='wishlist',
            name='customer',
        ),
        migrations.RemoveField(
            model_name='wishlistproduct',
            name='product_final',
        ),
        migrations.RemoveField(
            model_name='wishlistproduct',
            name='wish_list',
        ),
        migrations.AddField(
            model_name='salesbasket',
            name='name',
            field=models.CharField(default='Mi cesta', max_length=250, verbose_name='Name'),
            preserve_default=False,
        ),
        migrations.DeleteModel(
            name='WishList',
        ),
        migrations.DeleteModel(
            name='WishListProduct',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-05 11:49
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0040_auto_20170904_1816'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='purchasesalbaran',
            name='tax',
        ),
        migrations.RemoveField(
            model_name='purchasesbudget',
            name='tax',
        ),
        migrations.RemoveField(
            model_name='purchasesinvoice',
            name='tax',
        ),
        migrations.RemoveField(
            model_name='purchasesinvoicerectification',
            name='tax',
        ),
        migrations.RemoveField(
            model_name='purchasesorder',
            name='tax',
        ),
        migrations.RemoveField(
            model_name='purchasesticket',
            name='tax',
        ),
        migrations.RemoveField(
            model_name='purchasesticketrectification',
            name='tax',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-16 12:49
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0028_saleslineorderoption'),
    ]

    operations = [
        migrations.AlterField(
            model_name='provider',
            name='payment_methods',
            field=models.CharField(blank=True, choices=[(b'AMA', 'Amazon'), (b'TRA', 'Wire transfer'), (b'CAR', 'Card'), (b'CAS', 'Cash'), (b'CRE', 'Credit'), (b'PYP', 'Paypal'), (b'30C', '30 day credit'), (b'60C', '60 day credit'), (b'90C', '90 day credit')], max_length=3, null=True, verbose_name='Payment methods'),
        ),
        migrations.AlterField(
            model_name='salesorder',
            name='payment_detail',
            field=models.CharField(blank=True, choices=[(b'AMA', 'Amazon'), (b'TRA', 'Wire transfer'), (b'CAR', 'Card'), (b'CAS', 'Cash'), (b'CRE', 'Credit'), (b'PYP', 'Paypal'), (b'30C', '30 day credit'), (b'60C', '60 day credit'), (b'90C', '90 day credit')], max_length=3, null=True, verbose_name='Payment detail'),
        ),
    ]



# -*- coding: utf-8 -*-
#
# django-codenerix-invoicing
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django import forms
from django.utils.translation import ugettext as _

from codenerix.forms import GenModelForm
from codenerix.widgets import WysiwygAngularInput
from codenerix_extensions.helpers import get_external_model, get_external_method
from codenerix_products.models import TypeTax

from .models_sales import Address
from .models_sales import Customer, CustomerDocument
from .models_sales import SalesBasket, SalesLineBasket
from .models_sales import SalesOrder, SalesLineOrder
from .models_sales import SalesAlbaran, SalesLineAlbaran
from .models_sales import SalesTicket, SalesLineTicket
from .models_sales import SalesTicketRectification, SalesLineTicketRectification
from .models_sales import SalesInvoice, SalesLineInvoice
from .models_sales import SalesInvoiceRectification, SalesLineInvoiceRectification
from .models_sales import SalesReservedProduct
from .models_sales import ReasonModification, ReasonModificationLineBasket, ReasonModificationLineOrder, ReasonModificationLineAlbaran, ReasonModificationLineTicket, ReasonModificationLineTicketRectification, ReasonModificationLineInvoice, ReasonModificationLineInvoiceRectification



class CustomerForm(GenModelForm):
    codenerix_external_field = forms.ModelChoiceField(
        label=Customer.foreignkey_external()['label'],
        queryset=get_external_model(Customer).objects.all()
    )

    class Meta:
        model = Customer
        exclude = ['balance', 'default_customer', ]
        autofill = {
            'codenerix_external_field': ['select', 3, Customer.foreignkey_external()['related']],
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['codenerix_external_field', 8],
                ['billing_series', 2],
                ['currency', 2],
                ['credit', 3],
                ['final_balance', 3],
                ['type_tax', 3],
                ['apply_equivalence_surcharge', 3],)
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['codenerix_external_field', 6],
                ['credit', 6],
                ['currency', 6],
                ['billing_series', 6],
                ['final_balance', 6],
                ['apply_equivalence_surcharge', 3],
                ['type_tax', 3],)
        ]
        return g

    @staticmethod
    def __groups_details_profile__():
        g = [
            (_('Details'), 12,
                ['billing_series', 6],
                ['credit', 6],
                ['currency', 6],
                ['final_balance', 6],
                ['apply_equivalence_surcharge', 3],
                ['type_tax', 3],)
        ]
        return g


class CustomerDocumentForm(GenModelForm):
    class Meta:
        model = CustomerDocument
        exclude = ['name_file', 'customer']

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['type_document', 6],
                ['doc_path', 6],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['customer', 6],
                ['type_document', 6],
                ['doc_path', 6],
                ['name_file', 6],)
        ]
        return g


class BasketForm(GenModelForm):
    class Meta:
        model = SalesBasket
        exclude = ['lock', 'code', 'parent_pk', 'payment', 'role']
        widgets = {
            'observations': WysiwygAngularInput()
        }
        autofill = {
            'address_delivery': ['select', 3, Address.foreignkey_external_delivery()['related'], 'customer'],
            'address_invoice': ['select', 3, Address.foreignkey_external_invoice()['related'], 'customer'],
        }

    def __groups__(self):
        g = [
            (_('Basket'), 12,
                ['customer', 6],
                ['date', 2],
                ['signed', 2],
                ['public', 2],
                ['billing_series', 4],
                ['address_delivery', 4],
                ['address_invoice', 4],
                ['name', 4],
                ['pos_slot', 4],
                ['haulier', 4],
                ['observations', 12],),
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Basket'), 12,
                ['customer', 5],
                ['name', 5],
                ['signed', 2],
                ['public', 2],
                ['code', 3],
                ['billing_series', 4],
                ['date', 4],
                ['observations', 6],
                ['address_delivery', 6],
                ['address_invoice', 6],
                ['lock', 6],
                ['role', 6],
                ['haulier', 4],
                ['pos_slot', 6],),
            (
                _('Total'), 12,
                ['subtotal', 6],
                ['discounts', 6],
                ['taxes', 6],
                ['total', 6],
            )
        ]
        return g


class LineBasketForm(GenModelForm):
    price = forms.FloatField(label=_('Price with tax'), widget=forms.NumberInput(attrs={"disabled": 'disabled'}))
    tax = forms.FloatField(label=_('Tax hidden'), widget=forms.NumberInput(attrs={"disabled": 'disabled'}))
    type_tax = forms.ModelChoiceField(label=_('Tax'), queryset=TypeTax.objects.all())

    class Meta:
        model = SalesLineBasket
        exclude = ['basket', 'price_recommended', 'equivalence_surcharges', 'equivalence_surcharge']
        autofill = {
            'product': ['select', 3, 'CDNX_products_productfinals_foreign_sales', ],
            'type_tax': ['select', 3, 'CDNX_products_typetaxs_foreing', ],
        }
        widgets = {
            'notes': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['product', 6],
                ['description', 6],
                ['quantity', 6],
                ['price_base', 6, {'extra': ['ng-controller=codenerixSalesLineBasketCtrl', 'ng-change=update_price()']}],
                ['price', 6],
                ['type_tax', 6, {'extra': ['ng-controller=codenerixSalesLineBasketCtrl', 'ng-blur=update_price()']}],
                ['tax', 6],
                ['discount', 6],
                ['notes', 6],)
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['budget', 6],
                ['product', 6],
                ['description', 6],
                ['quantity', 6],
                ['price_base', 6],
                ['price_recommended', 6],
                ['discount', 6],
                ['tax', 6],
                ['notes', 12]),
        ]
        return g


class LineBasketFormPack(GenModelForm):
    packs = forms.CharField()  # widget=forms.HiddenInput())

    class Meta:
        model = SalesLineBasket
        exclude = ['basket', 'price_recommended', 'tax', ]
        autofill = {
            'product': ['select', 3, 'CDNX_products_productfinals_foreign_sales_pack', ],
        }
        widgets = {
            'notes': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['product', 6],
                ['description', 6],
                ['quantity', 6],
                ['price_base', 6],
                ['discount', 6],
                ['notes', 6],)
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['budget', 6],
                ['product', 6],
                ['description', 6],
                ['quantity', 6],
                ['price_base', 6],
                ['price_recommended', 6],
                ['discount', 6],
                ['tax', 6],
                ['notes', 12]),
        ]
        return g


class OrderFromBudgetForm(GenModelForm):
    class Meta:
        model = SalesOrder
        fields = ['customer', 'budget', 'billing_series']
        autofill = {
            'customer': ['select', 3, 'CDNX_invoicing_customers_foreign_from_budget'],
            'budget': ['select', 3, 'CDNX_invoicing_salesbaskets_foreignkey_budget', 'customer'],
        }

    def __groups__(self):
        g = [
            (_('Select budget'), 12,
                ['customer', 4],
                ['billing_series', 4],
                ['budget', 4],)
        ]
        return g


class OrderFromShoppingCartForm(GenModelForm):
    class Meta:
        model = SalesOrder
        fields = ['customer', 'budget', 'billing_series']
        autofill = {
            'customer': ['select', 3, 'CDNX_invoicing_customers_foreign_from_shoppingcart'],
            'budget': ['select', 3, 'CDNX_invoicing_salesbaskets_foreignkey_shoppingcart', 'customer'],
        }

    def __groups__(self):
        g = [
            (_('Select budget'), 12,
                ['customer', 4],
                ['billing_series', 4],
                ['budget', 4],)
        ]
        return g


class OrderForm(GenModelForm):
    class Meta:
        model = SalesOrder
        exclude = ['lock', 'code', 'parent_pk', 'budget', 'payment']
        widgets = {
            'observations': WysiwygAngularInput()
        }

    def __init__(self, *args, **kwargs):
        super(OrderForm, self).__init__(*args, **kwargs)

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['customer', 4],
                ['billing_series', 2],
                ['date', 2],
                ['storage', 4],
                ['status_order', 4],
                ['payment_detail', 4],
                ['source', 4],
                ['number_tracking', 6],
                ['observations', 12],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        info_customer = get_external_method(Customer, Customer.CodenerixMeta.force_methods['info_customer_details'][0])

        g = [
            (
                _('Details'), 12,
                ['customer', 6],
                ['budget', 6],
                ['date', 6],
                ['code', 6],
                ['billing_series', 2],
                ['storage', 6],
                ['status_order', 6],
                ['payment_detail', 6],
                ['payment', 6],
                ['source', 6],
                ['number_tracking', 6],
                ['observations', 6],
                ['lock', 6],
            ),
        ]
        for info in info_customer:
            g.append(info)
        g.append(
            (
                _('Total'), 12,
                ['subtotal', 6],
                ['discounts', 6],
                ['taxes', 6],
                ['total', 6],
            )
        )
        return g


class LineOrderForm(GenModelForm):
    class Meta:
        model = SalesLineOrder
        exclude = ['order', 'line_budget', 'tax', 'price_recommended', 'equivalence_surcharge', 'equivalence_surcharges']
        autofill = {
            'product': ['select', 3, 'CDNX_products_productfinals_foreign_sales'],
        }
        widgets = {
            'notes': WysiwygAngularInput()
        }

    def clean(self):
        cleaned_data = super(LineOrderForm, self).clean()
        product = cleaned_data.get('product')
        if product.product.force_stock:
            quantity = cleaned_data.get('quantity')
            if product.stock_real < quantity:
                self.add_error("quantity", _("No hay tantos productos en Stock"))

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['product', 6],
                ['description', 6],
                ['quantity', 6],
                ['price_base', 6],
                ['discount', 6],
                ['notes', 12])
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['order', 6],
                ['line_budget', 6],
                ['product', 6],
                ['description', 6],
                ['quantity', 6],
                ['price_base', 6],
                ['price_recommended', 6],
                ['discount', 6],
                ['tax', 6],
                ['notes', 6],)
        ]
        return g


class LineOrderFormEdit(LineOrderForm):
    reason = forms.ModelChoiceField(label=_('Reason of modification'), queryset=ReasonModification.objects.all().order_by('code'))

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['product', 6],
                ['description', 6],
                ['quantity', 6],
                ['price_base', 6],
                ['discount', 6],
                ['reason', 6],
                ['notes', 12])
        ]
        return g


class AlbaranForm(GenModelForm):
    class Meta:
        model = SalesAlbaran
        exclude = ['lock', 'code', 'parent_pk']
        widgets = {
            'observations': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['date', 6],
                ['billing_series', 6],
                ['summary_delivery', 6],
                ['observations', 6],),
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['date', 6],
                ['code', 6],
                ['billing_series', 6],
                ['summary_delivery', 6],
                ['lock', 6],
                ['observations', 6],),
            (
                _('Total'), 12,
                ['subtotal', 6],
                ['discounts', 6],
                ['taxes', 6],
                ['total', 6],
            )
        ]
        return g


class LineAlbaranForm(GenModelForm):
    albaran_pk = forms.IntegerField(widget=forms.HiddenInput())
    order = forms.ModelChoiceField(label=_('Sales order'), queryset=SalesOrder.objects.all())

    class Meta:
        model = SalesLineAlbaran
        exclude = ['albaran', 'invoiced']
        autofill = {
            'order': ['select', 3, 'CDNX_invoicing_ordersaless_foreign', 'albaran_pk'],
            'line_order': ['select', 3, 'CDNX_invoicing_lineordersaless_foreign', 'order'],
        }
        widgets = {
            'notes': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['order', 5],
                ['line_order', 5],
                ['quantity', 2],
                ['notes', 12])
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['albaran', 6],
                ['line_order', 6],
                ['line_order__product', 6],
                ['line_order__description', 6],
                ['invoiced', 6],
                ['quantity', 6],
                ['line_order__price_base', 6],
                ['line_order__price_recommended', 6],
                ['line_order__discount', 6],
                ['line_order__tax', 6],
                ['notes', 6])
        ]
        return g


class TicketForm(GenModelForm):
    class Meta:
        model = SalesTicket
        exclude = ['lock', 'code', 'parent_pk']
        widgets = {
            'observations': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['customer', 6],
                ['billing_series', 3],
                ['date', 3],
                ['observations', 12],)
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['customer', 6],
                ['date', 6],
                ['code', 6],
                ['billing_series', 6],
                ['lock', 6],
                ['observations', 6],),
            (
                _('Total'), 12,
                ['subtotal', 6],
                ['discounts', 6],
                ['taxes', 6],
                ['total', 6],
            )
        ]
        return g


class LineTicketForm(GenModelForm):
    ticket_pk = forms.IntegerField(widget=forms.HiddenInput())
    order = forms.ModelChoiceField(label=_('Sales order'), queryset=SalesOrder.objects.all())

    class Meta:
        model = SalesLineTicket
        exclude = ['ticket', 'tax', 'price_recommended']
        autofill = {
            'order': ['select', 3, 'CDNX_invoicing_ordersaless_foreign', 'ticket_pk'],
            'line_order': ['select', 3, 'CDNX_invoicing_lineordersaless_foreign_custom', 'order'],
        }
        widgets = {
            'notes': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['order', 6],
                ['line_order', 6],
                ['description', 6],
                ['quantity', 6],
                ['price_base', 6],
                ['discount', 6],
                ['notes', 12])
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['ticket', 6],
                ['line_order', 6],
                ['line_order__product', 6],
                ['description', 6],
                ['quantity', 6],
                ['discount', 6],
                ['price_base', 6],
                ['price_recommended', 6],
                ['tax', 6],
                ['notes', 6])
        ]
        return g


class TicketRectificationForm(GenModelForm):
    class Meta:
        model = SalesTicketRectification
        exclude = ['lock', 'parent_pk', 'code']
        widgets = {
            'observations': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['date', 4],
                ['billing_series', 4],
                ['ticket', 4],
                ['observations', 12],)
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['ticket', 6],
                ['date', 6],
                ['code', 6],
                ['tax', 6],
                ['observations', 6],),
            (
                _('Total'), 12,
                ['subtotal', 6],
                ['discounts', 6],
                ['taxes', 6],
                ['total', 6],
            )
        ]
        return g


class TicketRectificationUpdateForm(GenModelForm):
    class Meta:
        model = SalesTicketRectification
        exclude = ['lock', 'parent_pk', 'ticket', 'code']
        widgets = {
            'observations': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['date', 6],
                ['billing_series', 6],
                ['observations', 12],)
        ]
        return g


class LineTicketRectificationForm(GenModelForm):
    ticket_rectification_pk = forms.IntegerField(widget=forms.HiddenInput())

    class Meta:
        model = SalesLineTicketRectification
        exclude = ['ticket_rectification', 'equivalence_surcharges']
        autofill = {
            'line_ticket': ['select', 3, 'CDNX_invoicing_lineticketsaless_foreign', 'ticket_rectification_pk'],
        }
        widgets = {
            'notes': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['line_ticket', 6],
                ['quantity', 6],
                ['notes', 12])
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['ticket_rectification', 6],
                ['line_ticket', 6],
                ['line_ticket__product', 6],
                ['line_ticket__description', 6],
                ['quantity', 6],
                ['line_ticket__price_base', 6],
                ['line_ticket__tax', 6],
                ['line_ticket__price_recommended', 6],
                ['line_ticket__discount', 6],
                ['notes', 6])
        ]
        return g


class LineTicketRectificationLinkedForm(GenModelForm):
    class Meta:
        model = SalesLineTicketRectification
        exclude = ['ticket_rectification', 'line_ticket', 'equivalence_surcharges']
        widgets = {
            'notes': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['quantity', 3],
                ['notes', 9])
        ]
        return g


class InvoiceForm(GenModelForm):
    class Meta:
        model = SalesInvoice
        exclude = ['lock', 'code', 'parent_pk']
        widgets = {
            'observations': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['customer', 4],
                ['date', 4],
                ['billing_series', 4],
                ['summary_invoice', 6],
                ['observations', 6],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['customer', 6],
                ['date', 6],
                ['code', 6],
                ['billing_series', 6],
                ['observations', 6],),
            (
                _('Total'), 12,
                ['subtotal', 6],
                ['discounts', 6],
                ['taxes', 6],
                ['total', 6],
            )
        ]
        return g


class LineInvoiceForm(GenModelForm):
    invoice_pk = forms.IntegerField(widget=forms.HiddenInput())
    order = forms.ModelChoiceField(label=_('Sales order'), queryset=SalesOrder.objects.all())

    class Meta:
        model = SalesLineInvoice
        exclude = ['invoice', 'tax', 'price_recommended', 'equivalence_surcharges', 'equivalence_surcharge']
        autofill = {
            'order': ['select', 3, 'CDNX_invoicing_ordersaless_foreign', 'invoice_pk'],
            'line_order': ['select', 3, 'CDNX_invoicing_lineordersaless_foreign_custom', 'order'],
        }
        widgets = {
            'notes': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['order', 6],
                ['line_order', 6],
                ['description', 12],
                ['quantity', 4],
                ['price_base', 4],
                ['discount', 4],
                ['notes', 12])
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['invoice', 6],
                ['line_order', 6],
                ['product', 6],
                ['description', 6],
                ['quantity', 6],
                ['price_base', 6],
                ['price_recommended', 6],
                ['discount', 6],
                ['tax', 6],
                ['notes', 6])
        ]
        return g


class InvoiceRectificationForm(GenModelForm):
    class Meta:
        model = SalesInvoiceRectification
        exclude = ['lock', 'code', 'parent_pk']
        widgets = {
            'observations': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['date', 6],
                ['invoice', 6],
                ['billing_series', 6],
                ['observations', 6],)
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['invoice', 6],
                ['date', 6],
                ['code', 6],
                ['observations', 6],),
            (
                _('Total'), 12,
                ['subtotal', 6],
                ['discounts', 6],
                ['taxes', 6],
                ['total', 6],
            )
        ]
        return g


class InvoiceRectificationUpdateForm(GenModelForm):
    class Meta:
        model = SalesInvoiceRectification
        exclude = ['lock', 'code', 'parent_pk', 'invoice']
        widgets = {
            'observations': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['date', 6],
                ['billing_series', 6],
                ['observations', 12],)
        ]
        return g


class LineInvoiceRectificationForm(GenModelForm):
    invoice_rectification_pk = forms.IntegerField(widget=forms.HiddenInput())

    class Meta:
        model = SalesLineInvoiceRectification
        exclude = ['invoice_rectification']
        autofill = {
            'line_invoice': ['select', 3, 'CDNX_invoicing_lineinvoicessaless_foreign', 'invoice_rectification_pk'],
        }
        widgets = {
            'notes': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['line_invoice', 6],
                ['quantity', 6],
                ['notes', 12])
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['invoice_rectification', 6],
                ['line_invoice', 6],
                ['line_invoice__description', 6],
                ['quantity', 6],
                ['line_invoice__price_base', 6],
                ['line_invoice__tax', 6],
                ['line_invoice__discount', 6],
                ['notes', 6])
        ]
        return g


class LineInvoiceRectificationLinkedForm(GenModelForm):
    class Meta:
        model = SalesLineInvoiceRectification
        exclude = ['invoice_rectification', 'line_invoice']
        widgets = {
            'notes': WysiwygAngularInput()
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['quantity', 3],
                ['notes', 9])
        ]
        return g


class ReservedProductForm(GenModelForm):
    class Meta:
        model = SalesReservedProduct
        exclude = []

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['customer', 4],
                ['product', 4],
                ['quantity', 4],)
        ]
        return g


class ReasonModificationForm(GenModelForm):
    class Meta:
        model = ReasonModification
        exclude = []

    def __groups__(self):
        return [
            (
                _('Details'), 12,
                ['code', 6],
                ['name', 6],
                ['enable', 6],
            )
        ]

    @staticmethod
    def __groups_details__():
        return [
            (
                _('Details'), 12,
                ['code', 6],
                ['name', 6],
                ['enable', 6],
            )
        ]


class ReasonModificationLineForm(GenModelForm):
    doc = forms.FloatField(label=_('Document'), widget=forms.NumberInput(attrs={"disabled": 'disabled'}))
    
    class Meta:
        exclude = ['user', ]

    def __groups__(self):
        return [
            (
                _('Details'), 12,
                ['date', 6],
                ['line', 6],
                ['reason', 6],
                ['quantity', 6],
                ['doc', 6]
            )
        ]

    @staticmethod
    def __groups_details__():
        return [
            (
                _('Details'), 12,
                ['date', 6],
                ['line', 6],
                ['reason', 6],
                ['quantity', 6],
            )
        ]


class ReasonModificationLineBasketForm(ReasonModificationLineForm):
    class Meta(ReasonModificationLineForm.Meta):
        model = ReasonModificationLineBasket
        autofill = {
            'line': ['select', 3, 'CDNX_invoicing_linebasketsaless_foreign', 'doc']
        }


class ReasonModificationLineOrderForm(ReasonModificationLineForm):
    class Meta(ReasonModificationLineForm.Meta):
        model = ReasonModificationLineOrder
        autofill = {
            'line': ['select', 3, 'CDNX_invoicing_lineordersaless_foreign', 'doc']
        }


class ReasonModificationLineAlbaranForm(ReasonModificationLineForm):
    class Meta(ReasonModificationLineForm.Meta):
        model = ReasonModificationLineAlbaran
        autofill = {
            'line': ['select', 3, 'CDNX_invoicing_linealbaransaless_foreign', 'doc']
        }


class ReasonModificationLineTicketForm(ReasonModificationLineForm):
    class Meta(ReasonModificationLineForm.Meta):
        model = ReasonModificationLineTicket
        autofill = {
            'line': ['select', 3, 'CDNX_invoicing_lineticketsaless_foreign', 'doc']
        }


class ReasonModificationLineTicketRectificationForm(ReasonModificationLineForm):
    class Meta(ReasonModificationLineForm.Meta):
        model = ReasonModificationLineTicketRectification
        autofill = {
            'line': ['select', 3, 'CDNX_invoicing_lineticketrectificationsaless_sublist_foreign', 'doc']
        }


class ReasonModificationLineInvoiceForm(ReasonModificationLineForm):
    class Meta(ReasonModificationLineForm.Meta):
        model = ReasonModificationLineInvoice
        autofill = {
            'line': ['select', 3, 'CDNX_invoicing_lineinvoicessaless_foreign', 'doc']
        }


class ReasonModificationLineInvoiceRectificationForm(ReasonModificationLineForm):
    class Meta(ReasonModificationLineForm.Meta):
        model = ReasonModificationLineInvoiceRectification
        autofill = {
            'line': ['select', 3, 'CDNX_invoicing_lineinvoicerectificationsaless_sublist_foreign', 'doc']
        }



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-01 13:12
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='purchaseslineorder',
            name='order',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='line_order_purchases', to='codenerix_invoicing.PurchasesOrder', verbose_name='Orden'),
        ),
        migrations.AlterField(
            model_name='purchasesorderdocument',
            name='order',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='orderdocument_purchases', to='codenerix_invoicing.PurchasesOrder', verbose_name='Orden'),
        ),
        migrations.AlterField(
            model_name='saleslineorder',
            name='order',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='line_order_sales', to='codenerix_invoicing.SalesOrder', verbose_name='Orden'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-31 16:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0031_auto_20170831_1643'),
    ]

    operations = [
        migrations.AddField(
            model_name='saleslinealbaran',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
        migrations.AddField(
            model_name='saleslinebasket',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
        migrations.AddField(
            model_name='saleslineinvoice',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
        migrations.AddField(
            model_name='saleslineinvoicerectification',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
        migrations.AddField(
            model_name='saleslineorder',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
        migrations.AddField(
            model_name='saleslineticket',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
        migrations.AddField(
            model_name='saleslineticketrectification',
            name='removed',
            field=models.BooleanField(default=False, editable=False, verbose_name='Removed'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-01 11:14
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0034_auto_20170901_1256'),
    ]

    operations = [
        migrations.RenameField(
            model_name='saleslinebasket',
            old_name='price',
            new_name='price_base',
        ),
        migrations.RenameField(
            model_name='saleslineinvoice',
            old_name='price',
            new_name='price_base',
        ),
        migrations.RenameField(
            model_name='saleslineorder',
            old_name='price',
            new_name='price_base',
        ),
        migrations.RenameField(
            model_name='saleslineticket',
            old_name='price',
            new_name='price_base',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-04 08:49
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0035_auto_20170901_1314'),
    ]

    operations = [
        migrations.AddField(
            model_name='salesalbaran',
            name='equivalence_surcharges',
            field=models.FloatField(default=0, editable=False, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='salesbasket',
            name='equivalence_surcharges',
            field=models.FloatField(default=0, editable=False, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='salesinvoice',
            name='equivalence_surcharges',
            field=models.FloatField(default=0, editable=False, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='salesinvoicerectification',
            name='equivalence_surcharges',
            field=models.FloatField(default=0, editable=False, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='saleslinealbaran',
            name='equivalence_surcharges',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='saleslinebasket',
            name='equivalence_surcharge',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Equivalence surcharge (%)'),
        ),
        migrations.AddField(
            model_name='saleslinebasket',
            name='equivalence_surcharges',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='saleslineinvoice',
            name='equivalence_surcharge',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Equivalence surcharge (%)'),
        ),
        migrations.AddField(
            model_name='saleslineinvoice',
            name='equivalence_surcharges',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='saleslineinvoicerectification',
            name='equivalence_surcharges',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='saleslineorder',
            name='equivalence_surcharge',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Equivalence surcharge (%)'),
        ),
        migrations.AddField(
            model_name='saleslineorder',
            name='equivalence_surcharges',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='saleslineticket',
            name='equivalence_surcharge',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Equivalence surcharge (%)'),
        ),
        migrations.AddField(
            model_name='saleslineticket',
            name='equivalence_surcharges',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='saleslineticketrectification',
            name='equivalence_surcharges',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='salesorder',
            name='equivalence_surcharges',
            field=models.FloatField(default=0, editable=False, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='salesticket',
            name='equivalence_surcharges',
            field=models.FloatField(default=0, editable=False, verbose_name='Equivalence surcharge'),
        ),
        migrations.AddField(
            model_name='salesticketrectification',
            name='equivalence_surcharges',
            field=models.FloatField(default=0, editable=False, verbose_name='Equivalence surcharge'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-28 08:50
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0016_auto_20170419_1134'),
    ]

    operations = [
        migrations.AddField(
            model_name='haulier',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-15 21:41
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0047_auto_20170907_1859'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cashdiary',
            name='closed_amount',
        ),
        migrations.RemoveField(
            model_name='cashdiary',
            name='opened_amount',
        ),
        migrations.AddField(
            model_name='cashdiary',
            name='closed_cards',
            field=models.FloatField(blank=True, null=True, verbose_name='Closed Cards'),
        ),
        migrations.AddField(
            model_name='cashdiary',
            name='closed_cash',
            field=models.FloatField(blank=True, null=True, verbose_name='Closed Cash'),
        ),
        migrations.AddField(
            model_name='cashdiary',
            name='opened_cards',
            field=models.FloatField(default=0, verbose_name='Opened Cards'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='cashdiary',
            name='opened_cash',
            field=models.FloatField(default=0, verbose_name='Opened Cash'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='cashmovement',
            name='kind',
            field=models.CharField(choices=[('AMA', 'Amazon'), ('TRA', 'Wire transfer'), ('CAR', 'Card'), ('CAS', 'Cash'), ('CRE', 'Credit'), ('PYP', 'Paypal'), ('30C', '30 day credit'), ('60C', '60 day credit'), ('90C', '90 day credit')], max_length=3, verbose_name='Kind'),
        ),
        migrations.AlterField(
            model_name='cashmovement',
            name='kind_card',
            field=models.CharField(blank=True, choices=[('VIS', 'Visa'), ('MAS', 'MasterCard'), ('AME', 'American Express'), ('OTH', 'Other')], max_length=3, null=True, verbose_name='Kind Card'),
        ),
    ]
